<?php
/**
 * Register Blocks.
 *
 * @package Gutenberg Blocks Alike.
 *
 */

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/block-editor/tutorials/block-tutorial/writing-your-first-block-type/
 */
function alike_create_gt_block() {

	register_block_type_from_metadata( RA_GUTENBERG_BLOCK_DIR . '/blocks/compare-table' );
	register_block_type_from_metadata( RA_GUTENBERG_BLOCK_DIR . '/blocks/comare-group' );
	register_block_type_from_metadata( RA_GUTENBERG_BLOCK_DIR . '/blocks/compare-row', [
		'render_callback' => 'alike_display_table_content'
	] );
}
add_action( 'init', 'alike_create_gt_block' );

if(!function_exists('alike_display_table_content')){
	/**
	 * Display Table Content 
	 * Collback function for alike row,  dynamic content 
	 */
	function alike_display_table_content( $attributes ) {
		if(isset($_GET['ids']) && $_GET['ids'] == ''){
			die();
		}
		$get_id = isset($_GET['ids']) ? $_GET['ids'] : '';

		$data = alike_get_generated_data($attributes, $get_id);
		$html = '';
		$html .= '<tr class="'.$data['row'].'">';
		if(!empty($data['generated'])){
			foreach($data['generated'] as $value){
				$html .='<td>'.wp_kses_post($value).'</td>';
			} 
		}
		$html .= '</tr>';
		return  $html;
	}
}

if(!function_exists('alike_get_generated_data')){
	/**
	 * Generate data for display table 
	 */

	function alike_get_generated_data($attrs, $id) {
		$get_id_array = explode(',', $id);
		$temp = [];
		$generated_data = [];
		$default_title = str_replace('_', ' ',  $attrs['data_type']); 
		$generated_data['title']= (isset($attrs['custom_title']) && '' != $attrs['custom_title']) ? $attrs['custom_title'] : ucfirst($default_title); 
		foreach($get_id_array as $data){
			switch ($attrs['data_type']) {
				case 'post_keys':
				$generated_data[$data] = alike_get_data($attrs['data_value'], $data, $attrs);
				break;
				case 'meta_keys':
				$generated_data[$data] = alike_get_meta_key($attrs['data_value'], $data, $attrs);
					break;
				case 'taxonomy_keys':
				$generated_data[$data] = alike_get_taxonomy_keys($attrs['data_value'], $data);
				break;	
			}	   
		}
		$temp['generated'] = $generated_data;
		
		$temp['row']= alike_get_difference( $generated_data );
		return $temp;
	}
}

if(!function_exists('alike_get_data')){
	/**
	 * Get data for table row 
	 */
	function alike_get_data($data_type, $id, $attr) {
		
		switch ($data_type) {
			case 'post_title':
			return get_the_title($id);
			break;
			case 'post_thumbnail':
			return  alike_get_post_thumbnail($id, 'alike_thumbnail', $attr);
			case 'post_title_link':
				return '<h3><a href="' . get_the_permalink($id) . '">' . get_the_title($id) . '</a></h2>';
			case 'post_excerpt':
				return alike_get_post_content($id, 'excerpt');
			case 'post_content':
				return alike_get_post_content($id, 'content');
			case 'woocommerce_price':
				return alike_woocommerce_price($id);
			case 'woocommerce_add_to_cart':
				return alike_wocomemrce_add_to_cart( $id );	
			default:   
			return '';
		}
	}
}
if(!function_exists('alike_get_post_thumbnail')){
	/**
	 * Get Post thumbonil 
	 */
	function alike_get_post_thumbnail($id, $size, $attr) {
		$html = get_the_post_thumbnail($id, $size);
		if($attr['imageCaption'] == 1) {
			$html .= alike_get_image_caption($id);
		}
		return $html;
	}
}
if(!function_exists('alike_get_image_caption')){
	/**
	 * Get Image Caption 
	 * if row can display it 
	 */
	function alike_get_image_caption( $id ) {
		$html = '<div class="alike-image-caption">';
		
			$get_image_id = get_post_thumbnail_id($id);
			$caption = wp_get_attachment_caption($get_image_id);
			$title = get_the_title($get_image_id);

			$post_link = get_the_permalink($id);
				$html .='<a href="'.esc_attr($post_link).'" class="image-caption">'.esc_html($title).'</a>';
				$html .='<span>'.$caption.'</span>';
		$html .='</div>';
		return $html;
	}
}
if(!function_exists('alike_postype_builder_meta')){
	/**
	 * Make alike meta availiable for rest api 
	 */
	function alike_postype_builder_meta() {
		register_meta('comparison', 'alike_post_type_meta', [
			'single' => 'true',
			'type' => 'string',
			'show_in_rest' => true
		]);
	}
	add_action('init', 'alike_postype_builder_meta');
}

if(!function_exists('alike_get_difference')){
	/**
	 * Check data have any differcce 
	 */
	function alike_get_difference( $generated_data ) {
		$html =  'no-difference';
		unset($generated_data['title']);
		$is_uniq = array_unique($generated_data);
		if(count($is_uniq) <= 1 ){
			$html = 'no-difference';
		}else{
			$html = 'has-difference';
		}
		return $html;
	}
}
if(!function_exists('alike_get_post_content')){
	// get post content 
	function alike_get_post_content($id, $content_type='content') {

		$get_post = get_post($id);
		$html = '';
		if($content_type == 'content'){
			$html =  $get_post->post_content;			
		}else{
			$html =  $get_post->post_excerpt;	
		}
		return $html;	
	}
}

if(!function_exists('alike_woocommerce_price')){
	/**
	 * Get WooCommerce Price 
	 */
	function alike_woocommerce_price($id) {
		$html = '';
		if ( class_exists( 'WooCommerce' ) ) {
			global $woocommerce;
			$product = new WC_Product($id); 
			$html =  $product->get_price_html();
		} 
		return $html;  
	}
}
if(!function_exists('alike_wocomemrce_add_to_cart')){
	/**
 	* Get add to cart button 
 	*/
	function alike_wocomemrce_add_to_cart( $id ){
		$html = '';
		if ( class_exists( 'WooCommerce' ) ) {
			global $woocommerce;
			$_product = new WC_Product($id); 
			$html =  '<a rel="nofollow" href="/shop/?add-to-cart=' . $id . '" data-quantity="1" data-product_id="' . $id . '" data-product_sku="' . $_product->get_sku() . '" class="button add_to_cart_button ajax_add_to_cart">' . __('Add to cart', 'alike') . '</a>';
		} 
		return $html;  
	}
}
if(!function_exists('alike_get_meta_key')){
	/**
	 * Get alike meta key value 
	 */
	function alike_get_meta_key($value, $id, $display_type){
		$html = '';
		$post_meta = get_post_meta($id, $value, true);
		if($display_type['display_type'] == 'boolean'){
			$html = bool_meta_data($post_meta);
		}elseif($display_type['display_type'] == 'hyperlink'){
			$html = get_hyperlink($post_meta, $display_type);
		}else{
			$html = $post_meta;
		}
		return $html;
	}
}
if(!function_exists('bool_meta_data')){
/**
 * Check bool meta
 */
	function bool_meta_data( $post_data ) {
		$html = '';
		if (!empty($post_data)) {

			$bool = filter_var($post_data, FILTER_VALIDATE_BOOLEAN);

				if ($bool) {
					$html = '<span class="available"><i class="ion-checkmark-round"></i></span>';
				} else {
					$html = '<span class="not-available"><i class="ion-close-round"></i></span>';
				}
			} else {
				$html = '<span class="not-available"><i class="ion-close-round"></i></span>';
			}
			return $html;
		}
	}
if(!function_exists('alike_get_taxonomy_keys')){
	/**
 * Get taxonomy keys 
 */
	function alike_get_taxonomy_keys($data, $id) {
		if($data != 'post_format'){
			$get_taxonomy = wp_get_post_terms($id, $data,  array("fields" => "names"));
			$html = '';
			if(!empty($get_taxonomy)){
				foreach($get_taxonomy as $name){
					$html .='<span>'.$name.'</span>';
				}
			}
		}elseif($data == 'post_format'){
			$html = get_post_format( $id );
		}
		
		return $html;
	}
}
// hyperlink 
if(!function_exists('get_hyperlink')) {
	function get_hyperlink($post_meta, $display_type) {
		$class = $display_type['link_button_class'];
		$link_terget = $display_type['link_target'];
		$text = $display_type['button_text'];
		return '<a href="'.esc_url($post_meta).'" class="'.esc_attr($class).'" target="'.esc_attr($link_terget).'">'.esc_html($text).'</a>';
	}
}